.. Trio documentation master file, created by
   sphinx-quickstart on Sat Jan 21 19:11:14 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

===================================================
Trio: async programming for humans and snake people
===================================================

Trio is an experimental attempt to produce a production-quality,
`permissively licensed
<https://github.com/python-trio/trio/blob/master/LICENSE>`__,
async/await-native I/O library for Python, with an emphasis on
**usability** and **correctness** – we want to make it *easy* to
get things *right*.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   tutorial.rst
   reference-core.rst
   reference-io.rst
   reference-testing.rst
   reference-hazmat.rst
   design.rst
   history.rst

====================
 Indices and tables
====================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
